import { IExecutionContext } from "../../i-execution-context";
/**
 * Example response in JSON
 *
 * ```json
 * {
 *   "data": {
 *     "organization": {
 *       "teams": {
 *         "edges": [
 *           {
 *             "node": {
 *               "name": "admin",
 *               "members": {
 *                 "totalCount": 1,
 *                 "nodes": [
 *                   {
 *                     "login": "petermetz"
 *                   }
 *                 ]
 *               }
 *             }
 *           },
 *           {
 *             "node": {
 *               "name": "maintain",
 *               "members": {
 *                 "totalCount": 0,
 *                 "nodes": []
 *               }
 *             }
 *           },
 *           {
 *             "node": {
 *               "name": "read",
 *               "members": {
 *                 "totalCount": 0,
 *                 "nodes": []
 *               }
 *             }
 *           },
 *           {
 *             "node": {
 *               "name": "the-test-team",
 *               "members": {
 *                 "totalCount": 1,
 *                 "nodes": [
 *                   {
 *                     "login": "petermetz"
 *                   }
 *                 ]
 *               }
 *             }
 *           },
 *           {
 *             "node": {
 *               "name": "triage",
 *               "members": {
 *                 "totalCount": 0,
 *                 "nodes": []
 *               }
 *             }
 *           },
 *           {
 *             "node": {
 *               "name": "write",
 *               "members": {
 *                 "totalCount": 0,
 *                 "nodes": []
 *               }
 *             }
 *           }
 *         ]
 *       }
 *     }
 *   }
 * }
 * ```
 */
export declare const GQL_GET_TEAMS_OF_ORGANIZATION = "\nquery ($organizationName: String!){\n  organization(login: $organizationName) {\n    teams(first: 100) {\n      nodes {\n        name,\n        members {\n          nodes {\n            login\n          }\n        }\n      }\n    }\n  }\n}\n\n";
export declare function getTeamsOfOrganization(ctx: IExecutionContext, organizationName: string): Promise<readonly ITeamNodeEntity[]>;
export declare type IOrganizationTeamInfo = {
    readonly organization: Organization;
};
export declare type Organization = {
    readonly teams: Teams;
};
export declare type Teams = {
    readonly nodes?: readonly (ITeamNodeEntity)[] | null;
};
export declare type ITeamNodeEntity = {
    readonly name: string;
    readonly members: Members;
};
export declare type Members = {
    readonly nodes?: readonly (IMemberNodeEntity | null)[] | null;
};
export declare type IMemberNodeEntity = {
    readonly login: string;
};
